pub trait ActionGroupExt: IsA<ActionGroup> + 'static {
Show 17 methods
// Provided methods
fn action_added(&self, action_name: &str) { ... }
fn action_enabled_changed(&self, action_name: &str, enabled: bool) { ... }
fn action_removed(&self, action_name: &str) { ... }
fn action_state_changed(&self, action_name: &str, state: &Variant) { ... }
fn activate_action(&self, action_name: &str, parameter: Option<&Variant>) { ... }
fn change_action_state(&self, action_name: &str, value: &Variant) { ... }
fn is_action_enabled(&self, action_name: &str) -> bool { ... }
fn action_parameter_type(&self, action_name: &str) -> Option<VariantType> { ... }
fn action_state(&self, action_name: &str) -> Option<Variant> { ... }
fn action_state_hint(&self, action_name: &str) -> Option<Variant> { ... }
fn action_state_type(&self, action_name: &str) -> Option<VariantType> { ... }
fn has_action(&self, action_name: &str) -> bool { ... }
fn list_actions(&self) -> Vec<GString> { ... }
fn connect_action_added<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId { ... }
fn connect_action_enabled_changed<F: Fn(&Self, &str, bool) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId { ... }
fn connect_action_removed<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId { ... }
fn connect_action_state_changed<F: Fn(&Self, &str, &Variant) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Trait containing all ActionGroup methods.
Implementors
ActionGroup, Application, DBusActionGroup, RemoteActionGroup, SimpleActionGroup
Provided Methods
Sourcefn action_added(&self, action_name: &str)
fn action_added(&self, action_name: &str)
Emits the action-added signal on @self.
This function should only be called by [type@Gio.ActionGroup] implementations.
action_name
the name of an action in the group
Sourcefn action_enabled_changed(&self, action_name: &str, enabled: bool)
fn action_enabled_changed(&self, action_name: &str, enabled: bool)
Emits the action-enabled-changed signal on @self.
This function should only be called by [type@Gio.ActionGroup] implementations.
action_name
the name of an action in the group
enabled
whether the action is now enabled
Sourcefn action_removed(&self, action_name: &str)
fn action_removed(&self, action_name: &str)
Emits the action-removed signal on @self.
This function should only be called by [type@Gio.ActionGroup] implementations.
action_name
the name of an action in the group
Sourcefn action_state_changed(&self, action_name: &str, state: &Variant)
fn action_state_changed(&self, action_name: &str, state: &Variant)
Emits the action-state-changed signal on @self.
This function should only be called by [type@Gio.ActionGroup] implementations.
action_name
the name of an action in the group
state
the new state of the named action
Sourcefn activate_action(&self, action_name: &str, parameter: Option<&Variant>)
fn activate_action(&self, action_name: &str, parameter: Option<&Variant>)
);
g_debug (“Application has been terminated. Exiting.”);
exit (0);
## `action_name`
the name of the action to activate
## `parameter`
parameters to the activationSourcefn change_action_state(&self, action_name: &str, value: &Variant)
fn change_action_state(&self, action_name: &str, value: &Variant)
Request for the state of the named action within @self to be changed to @value.
The action must be stateful and @value must be of the correct type.
See action_state_type().
This call merely requests a change. The action may refuse to change
its state or may change its state to something other than @value.
See action_state_hint().
If the @value GVariant is floating, it is consumed.
action_name
the name of the action to request the change on
value
the new state
Sourcefn is_action_enabled(&self, action_name: &str) -> bool
fn is_action_enabled(&self, action_name: &str) -> bool
Sourcefn action_parameter_type(&self, action_name: &str) -> Option<VariantType>
fn action_parameter_type(&self, action_name: &str) -> Option<VariantType>
Queries the type of the parameter that must be given when activating the named action within @self.
When activating the action using activate_action(),
the [type@GLib.Variant] given to that function must be of the type returned
by this function.
In the case that this function returns NULL, you must not give any
[type@GLib.Variant], but NULL instead.
The parameter type of a particular action will never change but it is possible for an action to be removed and for a new action to be added with the same name but a different parameter type.
action_name
the name of the action to query
Returns
the parameter type
Sourcefn action_state(&self, action_name: &str) -> Option<Variant>
fn action_state(&self, action_name: &str) -> Option<Variant>
Queries the current state of the named action within @self.
If the action is not stateful then NULL will be returned. If the
action is stateful then the type of the return value is the type
given by action_state_type().
The return value (if non-NULL) should be freed with
GLib::Variant::unref() when it is no longer required.
action_name
the name of the action to query
Returns
the current state of the action
Sourcefn action_state_hint(&self, action_name: &str) -> Option<Variant>
fn action_state_hint(&self, action_name: &str) -> Option<Variant>
Requests a hint about the valid range of values for the state of the named action within @self.
If NULL is returned it either means that the action is not stateful
or that there is no hint about the valid range of values for the
state of the action.
If a [type@GLib.Variant] array is returned then each item in the array is a possible value for the state. If a [type@GLib.Variant] pair (ie: two-tuple) is returned then the tuple specifies the inclusive lower and upper bound of valid values for the state.
In any case, the information is merely a hint. It may be possible to have a state value outside of the hinted range and setting a value within the range may fail.
The return value (if non-NULL) should be freed with
GLib::Variant::unref() when it is no longer required.
action_name
the name of the action to query
Returns
the state range hint
Sourcefn action_state_type(&self, action_name: &str) -> Option<VariantType>
fn action_state_type(&self, action_name: &str) -> Option<VariantType>
Queries the type of the state of the named action within @self.
If the action is stateful then this function returns the
[type@GLib.VariantType] of the state. All calls to
change_action_state() must give a [type@GLib.Variant] of this
type and action_state() will return a [type@GLib.Variant]
of the same type.
If the action is not stateful then this function will return NULL.
In that case, action_state() will return NULL
and you must not call change_action_state().
The state type of a particular action will never change but it is possible for an action to be removed and for a new action to be added with the same name but a different state type.
action_name
the name of the action to query
Returns
the state type, if the action is stateful
Sourcefn has_action(&self, action_name: &str) -> bool
fn has_action(&self, action_name: &str) -> bool
Sourcefn list_actions(&self) -> Vec<GString>
fn list_actions(&self) -> Vec<GString>
Lists the actions contained within @self.
The caller is responsible for freeing the list with strfreev() when
it is no longer required.
Returns
a NULL-terminated array
of the names of the actions in the group
Sourcefn connect_action_added<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
fn connect_action_added<F: Fn(&Self, &str) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
Signals that a new action was just added to the group.
This signal is emitted after the action has been added and is now visible.
action_name
the name of the action in @action_group
Sourcefn connect_action_enabled_changed<F: Fn(&Self, &str, bool) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
fn connect_action_enabled_changed<F: Fn(&Self, &str, bool) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
Sourcefn connect_action_removed<F: Fn(&Self, &str) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
fn connect_action_removed<F: Fn(&Self, &str) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
Signals that an action is just about to be removed from the group.
This signal is emitted before the action is removed, so the action is still visible and can be queried from the signal handler.
action_name
the name of the action in @action_group
Sourcefn connect_action_state_changed<F: Fn(&Self, &str, &Variant) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
fn connect_action_state_changed<F: Fn(&Self, &str, &Variant) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".