Struct gio::AppInfoCreateFlags
source · [−]pub struct AppInfoCreateFlags { /* private fields */ }Implementations
sourceimpl AppInfoCreateFlags
impl AppInfoCreateFlags
pub const NONE: AppInfoCreateFlags = _
pub const NEEDS_TERMINAL: AppInfoCreateFlags = _
pub const SUPPORTS_URIS: AppInfoCreateFlags = _
pub const SUPPORTS_STARTUP_NOTIFICATION: AppInfoCreateFlags = _
sourcepub const fn empty() -> AppInfoCreateFlags
pub const fn empty() -> AppInfoCreateFlags
Returns an empty set of flags
sourcepub const fn all() -> AppInfoCreateFlags
pub const fn all() -> AppInfoCreateFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<AppInfoCreateFlags>
pub fn from_bits(bits: u32) -> Option<AppInfoCreateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> AppInfoCreateFlags
pub const fn from_bits_truncate(bits: u32) -> AppInfoCreateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AppInfoCreateFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> AppInfoCreateFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: AppInfoCreateFlags) -> bool
pub const fn intersects(&self, other: AppInfoCreateFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: AppInfoCreateFlags) -> bool
pub const fn contains(&self, other: AppInfoCreateFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: AppInfoCreateFlags)
pub fn insert(&mut self, other: AppInfoCreateFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: AppInfoCreateFlags)
pub fn remove(&mut self, other: AppInfoCreateFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: AppInfoCreateFlags)
pub fn toggle(&mut self, other: AppInfoCreateFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: AppInfoCreateFlags, value: bool)
pub fn set(&mut self, other: AppInfoCreateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.