pub struct ApplicationCommandLine { /* private fields */ }Expand description
local_command_line = test_local_cmdline;
… }
In this example of split commandline handling, options that start
with `--local-` are handled locally, all other options are passed
to the [signal@Gio.Application::command-line] handler which runs in the primary
instance.
The complete example can be found here:
[gapplication-example-cmdline2.c](https://gitlab.gnome.org/GNOME/glib/-/blob/HEAD/gio/tests/gapplication-example-cmdline2.c)
If handling the commandline requires a lot of work, it may be better to defer it.
```c
static gboolean
my_cmdline_handler (gpointer data)
{
GApplicationCommandLine *cmdline = data;
// do the heavy lifting in an idle
g_application_command_line_set_exit_status (cmdline, 0);
g_object_unref (cmdline); // this releases the application
return G_SOURCE_REMOVE;
}
static int
command_line (GApplication *application,
GApplicationCommandLine *cmdline)
{
// keep the application running until we are done with this commandline
g_application_hold (application);
g_object_set_data_full (G_OBJECT (cmdline),
"application", application,
(GDestroyNotify)g_application_release);
g_object_ref (cmdline);
g_idle_add (my_cmdline_handler, cmdline);
return 0;
}
```text
In this example the commandline is not completely handled before
the [`command-line`][struct@crate::Application#command-line] handler returns. Instead, we keep
a reference to the `GApplicationCommandLine` object and handle it
later (in this example, in an idle). Note that it is necessary to
hold the application until you are done with the commandline.
The complete example can be found here:
[gapplication-example-cmdline3.c](https://gitlab.gnome.org/GNOME/glib/-/blob/HEAD/gio/tests/gapplication-example-cmdline3.c)
## Properties
#### `arguments`
The commandline that caused this [`command-line`][struct@crate::Application#command-line]
signal emission.
Writable | Construct Only
#### `is-remote`
Whether this is a remote commandline.
Readable
#### `options`
The options sent along with the commandline.
Writable | Construct Only
#### `platform-data`
Platform-specific data for the commandline.
Writable | Construct Only
# Implements
[`ApplicationCommandLineExt`][trait@crate::prelude::ApplicationCommandLineExt], [`trait@glib::ObjectExt`], [`ApplicationCommandLineExtManual`][trait@crate::prelude::ApplicationCommandLineExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ApplicationCommandLine
impl ApplicationCommandLine
pub const NONE: Option<&'static ApplicationCommandLine> = None