Struct gio::ApplicationFlags
source · [−]pub struct ApplicationFlags { /* private fields */ }Implementations
sourceimpl ApplicationFlags
impl ApplicationFlags
pub const FLAGS_NONE: ApplicationFlags = _
pub const IS_SERVICE: ApplicationFlags = _
pub const IS_LAUNCHER: ApplicationFlags = _
pub const HANDLES_OPEN: ApplicationFlags = _
pub const HANDLES_COMMAND_LINE: ApplicationFlags = _
pub const SEND_ENVIRONMENT: ApplicationFlags = _
pub const NON_UNIQUE: ApplicationFlags = _
pub const CAN_OVERRIDE_APP_ID: ApplicationFlags = _
sourcepub const fn empty() -> ApplicationFlags
pub const fn empty() -> ApplicationFlags
Returns an empty set of flags
sourcepub const fn all() -> ApplicationFlags
pub const fn all() -> ApplicationFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ApplicationFlags>
pub fn from_bits(bits: u32) -> Option<ApplicationFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ApplicationFlags
pub const fn from_bits_truncate(bits: u32) -> ApplicationFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ApplicationFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> ApplicationFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ApplicationFlags) -> bool
pub const fn intersects(&self, other: ApplicationFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ApplicationFlags) -> bool
pub const fn contains(&self, other: ApplicationFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ApplicationFlags)
pub fn insert(&mut self, other: ApplicationFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ApplicationFlags)
pub fn remove(&mut self, other: ApplicationFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ApplicationFlags)
pub fn toggle(&mut self, other: ApplicationFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ApplicationFlags, value: bool)
pub fn set(&mut self, other: ApplicationFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.