Struct gio::AskPasswordFlags
source · [−]pub struct AskPasswordFlags { /* private fields */ }Implementations
sourceimpl AskPasswordFlags
impl AskPasswordFlags
pub const NEED_PASSWORD: AskPasswordFlags = _
pub const NEED_USERNAME: AskPasswordFlags = _
pub const NEED_DOMAIN: AskPasswordFlags = _
pub const SAVING_SUPPORTED: AskPasswordFlags = _
pub const ANONYMOUS_SUPPORTED: AskPasswordFlags = _
pub const TCRYPT: AskPasswordFlags = _
sourcepub const fn empty() -> AskPasswordFlags
pub const fn empty() -> AskPasswordFlags
Returns an empty set of flags
sourcepub const fn all() -> AskPasswordFlags
pub const fn all() -> AskPasswordFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<AskPasswordFlags>
pub fn from_bits(bits: u32) -> Option<AskPasswordFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> AskPasswordFlags
pub const fn from_bits_truncate(bits: u32) -> AskPasswordFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AskPasswordFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> AskPasswordFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: AskPasswordFlags) -> bool
pub const fn intersects(&self, other: AskPasswordFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: AskPasswordFlags) -> bool
pub const fn contains(&self, other: AskPasswordFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: AskPasswordFlags)
pub fn insert(&mut self, other: AskPasswordFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: AskPasswordFlags)
pub fn remove(&mut self, other: AskPasswordFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: AskPasswordFlags)
pub fn toggle(&mut self, other: AskPasswordFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: AskPasswordFlags, value: bool)
pub fn set(&mut self, other: AskPasswordFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.