Struct gio::ConverterFlags
source · [−]pub struct ConverterFlags { /* private fields */ }Implementations
sourceimpl ConverterFlags
impl ConverterFlags
pub const NONE: ConverterFlags = _
pub const INPUT_AT_END: ConverterFlags = _
pub const FLUSH: ConverterFlags = _
sourcepub const fn empty() -> ConverterFlags
pub const fn empty() -> ConverterFlags
Returns an empty set of flags
sourcepub const fn all() -> ConverterFlags
pub const fn all() -> ConverterFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<ConverterFlags>
pub fn from_bits(bits: u32) -> Option<ConverterFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> ConverterFlags
pub const fn from_bits_truncate(bits: u32) -> ConverterFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ConverterFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> ConverterFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: ConverterFlags) -> bool
pub const fn intersects(&self, other: ConverterFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: ConverterFlags) -> bool
pub const fn contains(&self, other: ConverterFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: ConverterFlags)
pub fn insert(&mut self, other: ConverterFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: ConverterFlags)
pub fn remove(&mut self, other: ConverterFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: ConverterFlags)
pub fn toggle(&mut self, other: ConverterFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: ConverterFlags, value: bool)
pub fn set(&mut self, other: ConverterFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.