Struct gio::ConverterInputStreamClass
source · [−]#[repr(C)]pub struct ConverterInputStreamClass(_);Trait Implementations
sourceimpl Deref for ConverterInputStreamClass
impl Deref for ConverterInputStreamClass
type Target = <FilterInputStream as ObjectType>::RustClassType
type Target = <FilterInputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ConverterInputStreamClass
impl DerefMut for ConverterInputStreamClass
sourceimpl IsClassFor for ConverterInputStreamClass
impl IsClassFor for ConverterInputStreamClass
type Instance = ConverterInputStream
type Instance = ConverterInputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ConverterInputStreamClass
impl Sync for ConverterInputStreamClass