Struct gio::ConverterOutputStreamClass
source · [−]#[repr(C)]pub struct ConverterOutputStreamClass(_);Trait Implementations
sourceimpl Deref for ConverterOutputStreamClass
impl Deref for ConverterOutputStreamClass
type Target = <FilterOutputStream as ObjectType>::RustClassType
type Target = <FilterOutputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ConverterOutputStreamClass
impl DerefMut for ConverterOutputStreamClass
sourceimpl IsClassFor for ConverterOutputStreamClass
impl IsClassFor for ConverterOutputStreamClass
type Instance = ConverterOutputStream
type Instance = ConverterOutputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ConverterOutputStreamClass
impl Sync for ConverterOutputStreamClass