pub struct DBusMessage { /* private fields */ }Expand description
A type for representing D-Bus messages that can be sent or received
on a DBusConnection.
Properties
locked
Readable
Implements
[trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl DBusMessage
impl DBusMessage
Sourcepub fn new() -> DBusMessage
pub fn new() -> DBusMessage
Sourcepub fn from_blob(
blob: &[u8],
capabilities: DBusCapabilityFlags,
) -> Result<DBusMessage, Error>
pub fn from_blob( blob: &[u8], capabilities: DBusCapabilityFlags, ) -> Result<DBusMessage, Error>
Creates a new D-Bus message from the data stored at @blob.
You must have previously called bytes_needed() on @blob,
and ensure that @blob is at least as long as the return value from that
function indicates. In particular, that means that @blob must be at least 16
bytes long (but will typically be much longer).
The byte order that the message was in can be retrieved using
byte_order().
If the @blob cannot be parsed, contains invalid fields, or contains invalid headers, [error@Gio.IOErrorEnum.INVALID_ARGUMENT] will be returned.
blob
a blob representing a binary D-Bus message
capabilities
flags describing what protocol features are supported
Returns
The D-Bus message
Sourcepub fn new_method_call(
name: Option<&str>,
path: &str,
interface_: Option<&str>,
method: &str,
) -> DBusMessage
pub fn new_method_call( name: Option<&str>, path: &str, interface_: Option<&str>, method: &str, ) -> DBusMessage
Sourcepub fn new_signal(path: &str, interface_: &str, signal: &str) -> DBusMessage
pub fn new_signal(path: &str, interface_: &str, signal: &str) -> DBusMessage
pub fn copy(&self) -> Result<DBusMessage, Error>
Sourcepub fn arg0(&self) -> Option<GString>
pub fn arg0(&self) -> Option<GString>
Convenience to get the first item in the body of @self.
See arg0_path() for returning object-path-typed
arg0 values.
Returns
The string item, or NULL if the first item in the body
of @self is not a string
Sourcepub fn byte_order(&self) -> DBusMessageByteOrder
pub fn byte_order(&self) -> DBusMessageByteOrder
Sourcepub fn destination(&self) -> Option<GString>
pub fn destination(&self) -> Option<GString>
Convenience getter for the [enum@Gio.DBusMessageHeaderField.DESTINATION] header field.
Returns
The value
Sourcepub fn error_name(&self) -> Option<GString>
pub fn error_name(&self) -> Option<GString>
Convenience getter for the [enum@Gio.DBusMessageHeaderField.ERROR_NAME] header field.
Returns
The value
Sourcepub fn flags(&self) -> DBusMessageFlags
pub fn flags(&self) -> DBusMessageFlags
Gets the flags for @self.
Returns
Flags that are set (typically values from the
DBusMessageFlags enumeration bitwise ORed together)
Sourcepub fn header(&self, header_field: DBusMessageHeaderField) -> Option<Variant>
pub fn header(&self, header_field: DBusMessageHeaderField) -> Option<Variant>
Gets a header field on @self.
The caller is responsible for checking the type of the returned [type@GLib.Variant] matches what is expected.
header_field
a 8-bit unsigned integer (typically a value from the
DBusMessageHeaderField enumeration)
Returns
A [type@GLib.Variant] with the value, or
NULL if the header was not found
Sourcepub fn interface(&self) -> Option<GString>
pub fn interface(&self) -> Option<GString>
Convenience getter for the [enum@Gio.DBusMessageHeaderField.INTERFACE] header field.
Returns
The value
Sourcepub fn member(&self) -> Option<GString>
pub fn member(&self) -> Option<GString>
Convenience getter for the [enum@Gio.DBusMessageHeaderField.MEMBER] header field.
Returns
The value
Sourcepub fn message_type(&self) -> DBusMessageType
pub fn message_type(&self) -> DBusMessageType
Gets the type of @self.
Returns
A 8-bit unsigned integer (typically a value from the
DBusMessageType enumeration)
Sourcepub fn num_unix_fds(&self) -> u32
Available on Unix only.
pub fn num_unix_fds(&self) -> u32
Convenience getter for the [enum@Gio.DBusMessageHeaderField.NUM_UNIX_FDS] header field.
Returns
The value
Sourcepub fn reply_serial(&self) -> u32
pub fn reply_serial(&self) -> u32
Convenience getter for the [enum@Gio.DBusMessageHeaderField.REPLY_SERIAL] header field.
Returns
The value
Sourcepub fn sender(&self) -> Option<GString>
pub fn sender(&self) -> Option<GString>
Convenience getter for the [enum@Gio.DBusMessageHeaderField.SENDER] header field.
Returns
The value
Sourcepub fn signature(&self) -> GString
pub fn signature(&self) -> GString
Convenience getter for the [enum@Gio.DBusMessageHeaderField.SIGNATURE header field.
This will always be non-NULL, but may be an empty string.
Returns
The value
Sourcepub fn unix_fd_list(&self) -> Option<UnixFDList>
Available on Unix only.
pub fn unix_fd_list(&self) -> Option<UnixFDList>
Gets the UNIX file descriptors associated with @self, if any.
This method is only available on UNIX.
The file descriptors normally correspond to G_VARIANT_TYPE_HANDLE
values in the body of the message. For example, if
[glib::Variant::handle()][crate::glib::Variant::handle()] returns 5, that is intended to be a
reference to the file descriptor that can be accessed by
g_unix_fd_list_get (list, 5, ...).
Returns
A UnixFDList or NULL if no
file descriptors are associated
Sourcepub fn new_method_error_literal(
&self,
error_name: &str,
error_message: &str,
) -> DBusMessage
pub fn new_method_error_literal( &self, error_name: &str, error_message: &str, ) -> DBusMessage
Sourcepub fn new_method_reply(&self) -> DBusMessage
pub fn new_method_reply(&self) -> DBusMessage
Sourcepub fn print(&self, indent: u32) -> GString
pub fn print(&self, indent: u32) -> GString
Produces a human-readable multi-line description of @self.
The contents and formatting are subject to change at any time and no ABI guarantees are given. Typical output looks something like this:
Flags: none
Version: 0
Serial: 4
Headers:
path -> objectpath '/org/gtk/GDBus/TestObject'
interface -> 'org.gtk.GDBus.TestInterface'
member -> 'GimmeStdout'
destination -> ':1.146'
Body: ()
UNIX File Descriptors:
(none)or
Flags: no-reply-expected
Version: 0
Serial: 477
Headers:
reply-serial -> uint32 4
destination -> ':1.159'
sender -> ':1.146'
num-unix-fds -> uint32 1
Body: ()
UNIX File Descriptors:
fd 12: dev=0:10,mode=020620,ino=5,uid=500,gid=5,rdev=136:2,size=0,atime=1273085037,mtime=1273085851,ctime=1272982635indent
indentation level
Returns
Human readable description of @self
Sourcepub fn set_body(&self, body: &Variant)
pub fn set_body(&self, body: &Variant)
Sets the body of @self.
As a side-effect the [enum@Gio.DBusMessageHeaderField.SIGNATURE] header field
is set to the type string of @body (or cleared if @body is NULL).
If @body is floating, @self assumes ownership of @body.
body
a [type@GLib.Variant] containing a tuple, or NULL if no body is
needed
Sourcepub fn set_byte_order(&self, byte_order: DBusMessageByteOrder)
pub fn set_byte_order(&self, byte_order: DBusMessageByteOrder)
Sourcepub fn set_destination(&self, value: Option<&str>)
pub fn set_destination(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.DESTINATION] header field.
value
the value to set
Sourcepub fn set_error_name(&self, value: Option<&str>)
pub fn set_error_name(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.ERROR_NAME] header field.
value
the value to set
Sourcepub fn set_flags(&self, flags: DBusMessageFlags)
pub fn set_flags(&self, flags: DBusMessageFlags)
Sets the flags to set on @self.
flags
flags for @self that are set (typically values from the
DBusMessageFlags enumeration bitwise ORed together)
Sourcepub fn set_header(
&self,
header_field: DBusMessageHeaderField,
value: Option<&Variant>,
)
pub fn set_header( &self, header_field: DBusMessageHeaderField, value: Option<&Variant>, )
Sets a header field on @self.
If @value is floating, @self assumes ownership of @value.
header_field
a 8-bit unsigned integer (typically a value from the
DBusMessageHeaderField enumeration)
value
a [type@GLib.Variant] to set the header field, or NULL
to clear the header field.
Sourcepub fn set_interface(&self, value: Option<&str>)
pub fn set_interface(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.INTERFACE] header field.
value
the value to set
Sourcepub fn set_member(&self, value: Option<&str>)
pub fn set_member(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.MEMBER] header field.
value
the value to set
Sourcepub fn set_message_type(&self, type_: DBusMessageType)
pub fn set_message_type(&self, type_: DBusMessageType)
Sets @self to be of @type_.
type_
a 8-bit unsigned integer (typically a value from the
DBusMessageType enumeration)
Sourcepub fn set_num_unix_fds(&self, value: u32)
Available on Unix only.
pub fn set_num_unix_fds(&self, value: u32)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.NUM_UNIX_FDS] header field.
value
the value to set
Sourcepub fn set_path(&self, value: Option<&str>)
pub fn set_path(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.PATH] header field.
value
the value to set
Sourcepub fn set_reply_serial(&self, value: u32)
pub fn set_reply_serial(&self, value: u32)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.REPLY_SERIAL] header field.
value
the value to set
Sourcepub fn set_sender(&self, value: Option<&str>)
pub fn set_sender(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.SENDER] header field.
value
the value to set
Sourcepub fn set_serial(&self, serial: u32)
pub fn set_serial(&self, serial: u32)
Sets the serial for @self.
The D-Bus specification does not allow the @serial to be zero.
serial
a serial number, which must not be zero
Sourcepub fn set_signature(&self, value: Option<&str>)
pub fn set_signature(&self, value: Option<&str>)
Convenience setter for the [enum@Gio.DBusMessageHeaderField.SIGNATURE] header field.
value
the value to set
Sourcepub fn set_unix_fd_list(&self, fd_list: Option<&impl IsA<UnixFDList>>)
Available on Unix only.
pub fn set_unix_fd_list(&self, fd_list: Option<&impl IsA<UnixFDList>>)
Sets the UNIX file descriptors associated with @self.
As a side-effect the [enum@Gio.DBusMessageHeaderField.NUM_UNIX_FDS] header
field is set to the number of fds in @fd_list (or cleared if
@fd_list is NULL).
This method is only available on UNIX.
When designing D-Bus APIs that are intended to be interoperable,
please note that non-GDBus implementations of D-Bus can usually only
access file descriptors if they are referenced by a value of type
G_VARIANT_TYPE_HANDLE in the body of the message.
fd_list
A UnixFDList, or NULL to clear
Sourcepub fn to_blob(
&self,
capabilities: DBusCapabilityFlags,
) -> Result<Vec<u8>, Error>
pub fn to_blob( &self, capabilities: DBusCapabilityFlags, ) -> Result<Vec<u8>, Error>
Serializes @self to a blob.
The byte order returned by byte_order() will be
used.
capabilities
flags describing what protocol features are supported
Returns
A pointer to a valid binary D-Bus message of @out_size bytes generated by @self
Sourcepub fn to_gerror(&self) -> Result<(), Error>
pub fn to_gerror(&self) -> Result<(), Error>
Encodes the error in @self as a [type@GLib.Error].
If @self is of type [enum@Gio.DBusMessageType.ERROR], this function
calls Gio::DBusError::set_dbus_error() using the information in the
[enum@Gio.DBusMessageHeaderField.ERROR_NAME] header field of @self as
well as the first string item in @self’s body.
If @self is not of type [enum@Gio.DBusMessageType.ERROR], this function does nothing and returns false.
Returns
true if @error was set, false otherwise
Sourcepub fn bytes_needed(blob: &[u8]) -> Result<isize, Error>
pub fn bytes_needed(blob: &[u8]) -> Result<isize, Error>
Utility function to calculate how many bytes are needed to completely deserialize the D-Bus message stored at @blob.
An error will be returned if @blob contains invalid data, or if not enough data is available to determine the size.
blob
a blob representing a binary D-Bus message.
Returns
Number of bytes needed or -1 if @error is set
pub fn connect_locked_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId