pub struct DBusObjectManagerClient { /* private fields */ }Expand description
problem cannot happen.
To avoid having the application connect to signals on the returned
DBusObjectProxy and DBusProxy objects, the
interface-added,
interface-removed,
g-properties-changed and
g-signal signals
are also emitted on the GDBusObjectManagerClient instance managing these
objects. The signals emitted are
interface-added,
interface-removed,
interface-proxy-properties-changed and
interface-proxy-signal.
Note that all callbacks and signals are emitted in the
thread-default main context (see
[glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()]) that the
GDBusObjectManagerClient object was constructed in. Additionally, the
DBusObjectProxy and DBusProxy objects
originating from the GDBusObjectManagerClient object will be created in
the same context and, consequently, will deliver signals in the
same main loop.
Properties
bus-type
If this property is not BusType::None, then
#GDBusObjectManagerClient:connection must be None and will be set to the
#GDBusConnection obtained by calling g_bus_get() with the value
of this property.
Writable | Construct Only
connection
The #GDBusConnection to use.
Readable | Writable | Construct Only
flags
Flags from the #GDBusObjectManagerClientFlags enumeration.
Readable | Writable | Construct Only
get-proxy-type-destroy-notify
A #GDestroyNotify for the #gpointer user_data in #GDBusObjectManagerClient:get-proxy-type-user-data.
Readable | Writable | Construct Only
get-proxy-type-func
The #GDBusProxyTypeFunc to use when determining what #GType to
use for interface proxies or None.
Readable | Writable | Construct Only
get-proxy-type-user-data
The #gpointer user_data to pass to #GDBusObjectManagerClient:get-proxy-type-func.
Readable | Writable | Construct Only
name
The well-known name or unique name that the manager is for.
Readable | Writable | Construct Only
name-owner
The unique name that owns #GDBusObjectManagerClient:name or None if
no-one is currently owning the name. Connect to the
#GObject::notify signal to track changes to this property.
Readable
object-path
The object path the manager is for.
Readable | Writable | Construct Only
Signals
interface-proxy-properties-changed
Emitted when one or more D-Bus properties on proxy changes. The
local cache has already been updated when this signal fires. Note
that both @changed_properties and @invalidated_properties are
guaranteed to never be None (either may be empty though).
This signal exists purely as a convenience to avoid having to connect signals to all interface proxies managed by @manager.
This signal is emitted in the thread-default main context
(see [glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()])
that @manager was constructed in.
interface-proxy-signal
Emitted when a D-Bus signal is received on @interface_proxy.
This signal exists purely as a convenience to avoid having to connect signals to all interface proxies managed by @manager.
This signal is emitted in the thread-default main context
(see [glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()])
that @manager was constructed in.
DBusObjectManager
interface-added
Emitted when @interface is added to @object.
This signal exists purely as a convenience to avoid having to connect signals to all objects managed by @manager.
interface-removed
Emitted when @interface has been removed from @object.
This signal exists purely as a convenience to avoid having to connect signals to all objects managed by @manager.
object-added
Emitted when @object is added to @manager.
object-removed
Emitted when @object is removed from @manager.
Implements
DBusObjectManagerClientExt, [trait@glib::ObjectExt], AsyncInitableExt, DBusObjectManagerExt, InitableExt, DBusObjectManagerClientExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl DBusObjectManagerClient
impl DBusObjectManagerClient
pub fn new_sync( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: Option<&str>, object_path: &str, cancellable: Option<&impl IsA<Cancellable>>, ) -> Result<DBusObjectManagerClient, Error>
pub fn new_sync_with_fn<F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: Option<&str>, object_path: &str, get_proxy_type_func: F, cancellable: Option<&impl IsA<Cancellable>>, ) -> Result<DBusObjectManagerClient, Error>
pub fn for_bus_sync( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, cancellable: Option<&impl IsA<Cancellable>>, ) -> Result<DBusObjectManagerClient, Error>
pub fn for_bus_sync_with_fn<F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, get_proxy_type_func: F, cancellable: Option<&impl IsA<Cancellable>>, ) -> Result<DBusObjectManagerClient, Error>
Sourcepub fn new<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static>(
connection: &DBusConnection,
flags: DBusObjectManagerClientFlags,
name: &str,
object_path: &str,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn new<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static>( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously creates a new #GDBusObjectManagerClient object.
This is an asynchronous failable constructor. When the result is
ready, @callback will be invoked in the thread-default main context
(see [glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()])
of the thread you are calling this method from. You can then call
g_dbus_object_manager_client_new_finish() to get the result. See
g_dbus_object_manager_client_new_sync() for the synchronous version.
connection
A #GDBusConnection.
flags
Zero or more flags from the #GDBusObjectManagerClientFlags enumeration.
name
The owner of the control object (unique or well-known name).
object_path
The object path of the control object.
get_proxy_type_func
A #GDBusProxyTypeFunc function or None to always construct #GDBusProxy proxies.
get_proxy_type_user_data
User data to pass to @get_proxy_type_func.
get_proxy_type_destroy_notify
Free function for @get_proxy_type_user_data or None.
cancellable
A #GCancellable or None
callback
A #GAsyncReadyCallback to call when the request is satisfied.
pub fn new_with_fn<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static, F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, get_proxy_type_func: F, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
pub fn new_future( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, ) -> Pin<Box<dyn Future<Output = Result<DBusObjectManagerClient, Error>> + 'static>>
pub fn new_future_with_fn<F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( connection: &DBusConnection, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, get_proxy_type_func: F, ) -> Pin<Box<dyn Future<Output = Result<DBusObjectManagerClient, Error>> + 'static>>
Sourcepub fn new_for_bus<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static>(
bus_type: BusType,
flags: DBusObjectManagerClientFlags,
name: &str,
object_path: &str,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn new_for_bus<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static>( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Like g_dbus_object_manager_client_new() but takes a #GBusType instead of a #GDBusConnection.
This is an asynchronous failable constructor. When the result is
ready, @callback will be invoked in the thread-default main context
(see [glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()])
of the thread you are calling this method from. You can
then call g_dbus_object_manager_client_new_for_bus_finish() to get the result. See
g_dbus_object_manager_client_new_for_bus_sync() for the synchronous version.
bus_type
A #GBusType.
flags
Zero or more flags from the #GDBusObjectManagerClientFlags enumeration.
name
The owner of the control object (unique or well-known name).
object_path
The object path of the control object.
get_proxy_type_func
A #GDBusProxyTypeFunc function or None to always construct #GDBusProxy proxies.
get_proxy_type_user_data
User data to pass to @get_proxy_type_func.
get_proxy_type_destroy_notify
Free function for @get_proxy_type_user_data or None.
cancellable
A #GCancellable or None
callback
A #GAsyncReadyCallback to call when the request is satisfied.
pub fn new_for_bus_with_fn<P: FnOnce(Result<DBusObjectManagerClient, Error>) + Send + Sync + 'static, F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, get_proxy_type_func: F, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
pub fn new_for_bus_future( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, ) -> Pin<Box<dyn Future<Output = Result<DBusObjectManagerClient, Error>> + 'static>>
pub fn new_for_bus_future_with_fn<F: Fn(&DBusObjectManagerClient, &str, Option<&str>) -> Type + Send + Sync + 'static>( bus_type: BusType, flags: DBusObjectManagerClientFlags, name: &str, object_path: &str, get_proxy_type_func: F, ) -> Pin<Box<dyn Future<Output = Result<DBusObjectManagerClient, Error>> + 'static>>
Sourceimpl DBusObjectManagerClient
impl DBusObjectManagerClient
pub const NONE: Option<&'static DBusObjectManagerClient> = None