Struct gio::DataInputStreamClass
source · [−]#[repr(C)]pub struct DataInputStreamClass(_);Trait Implementations
sourceimpl Deref for DataInputStreamClass
impl Deref for DataInputStreamClass
type Target = <BufferedInputStream as ObjectType>::RustClassType
type Target = <BufferedInputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for DataInputStreamClass
impl DerefMut for DataInputStreamClass
sourceimpl IsClassFor for DataInputStreamClass
impl IsClassFor for DataInputStreamClass
type Instance = DataInputStream
type Instance = DataInputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for DataInputStreamClass
impl Sync for DataInputStreamClass