Struct gio::DesktopAppInfoClass
source · [−]#[repr(C)]pub struct DesktopAppInfoClass(_);Trait Implementations
sourceimpl Deref for DesktopAppInfoClass
impl Deref for DesktopAppInfoClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for DesktopAppInfoClass
impl DerefMut for DesktopAppInfoClass
sourceimpl IsClassFor for DesktopAppInfoClass
impl IsClassFor for DesktopAppInfoClass
type Instance = DesktopAppInfo
type Instance = DesktopAppInfo
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for DesktopAppInfoClass
impl Sync for DesktopAppInfoClass