Struct gio::DriveStartFlags
source · [−]pub struct DriveStartFlags { /* private fields */ }Implementations
sourceimpl DriveStartFlags
impl DriveStartFlags
pub const NONE: DriveStartFlags = _
sourcepub const fn empty() -> DriveStartFlags
pub const fn empty() -> DriveStartFlags
Returns an empty set of flags
sourcepub const fn all() -> DriveStartFlags
pub const fn all() -> DriveStartFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<DriveStartFlags>
pub fn from_bits(bits: u32) -> Option<DriveStartFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> DriveStartFlags
pub const fn from_bits_truncate(bits: u32) -> DriveStartFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> DriveStartFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> DriveStartFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: DriveStartFlags) -> bool
pub const fn intersects(&self, other: DriveStartFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: DriveStartFlags) -> bool
pub const fn contains(&self, other: DriveStartFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: DriveStartFlags)
pub fn insert(&mut self, other: DriveStartFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: DriveStartFlags)
pub fn remove(&mut self, other: DriveStartFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: DriveStartFlags)
pub fn toggle(&mut self, other: DriveStartFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: DriveStartFlags, value: bool)
pub fn set(&mut self, other: DriveStartFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.