Struct gio::EmblemedIconClass
source · [−]#[repr(C)]pub struct EmblemedIconClass(_);Trait Implementations
sourceimpl Deref for EmblemedIconClass
impl Deref for EmblemedIconClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for EmblemedIconClass
impl DerefMut for EmblemedIconClass
sourceimpl IsClassFor for EmblemedIconClass
impl IsClassFor for EmblemedIconClass
type Instance = EmblemedIcon
type Instance = EmblemedIcon
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for EmblemedIconClass
impl Sync for EmblemedIconClass