pub struct File { /* private fields */ }Expand description
for
short. Entity tags are somewhat like a more abstract version of the
traditional mtime, and can be used to quickly determine if the file
has been modified from the version on the file system. See the
description of HTTP ETags in
RFC9110.
GFile Entity Tags are a very similar concept.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl File
impl File
Sourcepub fn new_tmp_async<P: FnOnce(Result<(File, FileIOStream), Error>) + 'static>(
tmpl: Option<impl AsRef<Path>>,
io_priority: Priority,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
Available on crate feature v2_74 only.
pub fn new_tmp_async<P: FnOnce(Result<(File, FileIOStream), Error>) + 'static>( tmpl: Option<impl AsRef<Path>>, io_priority: Priority, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
v2_74 only.Asynchronously opens a file in the preferred directory for temporary files (as returned by g_get_tmp_dir()) as g_file_new_tmp().
@tmpl should be a string in the GLib file name encoding
containing a sequence of six ‘X’ characters, and containing no
directory components. If it is None, a default template is used.
tmpl
Template for the file
name, as in g_file_open_tmp(), or None for a default template
io_priority
the I/O priority of the request
cancellable
optional #GCancellable object, None to ignore
callback
a #GAsyncReadyCallback to call when the request is done
pub fn new_tmp_future( tmpl: Option<impl AsRef<Path>>, io_priority: Priority, ) -> Pin<Box<dyn Future<Output = Result<(File, FileIOStream), Error>> + 'static>>
v2_74 only.Sourcepub fn new_tmp_dir_async<P: FnOnce(Result<File, Error>) + 'static>(
tmpl: Option<impl AsRef<Path>>,
io_priority: Priority,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
Available on crate feature v2_74 only.
pub fn new_tmp_dir_async<P: FnOnce(Result<File, Error>) + 'static>( tmpl: Option<impl AsRef<Path>>, io_priority: Priority, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
v2_74 only.Asynchronously creates a directory in the preferred directory for temporary files (as returned by g_get_tmp_dir()) as g_dir_make_tmp().
@tmpl should be a string in the GLib file name encoding
containing a sequence of six ‘X’ characters, and containing no
directory components. If it is None, a default template is used.
tmpl
Template for the file
name, as in g_dir_make_tmp(), or None for a default template
io_priority
the I/O priority of the request
cancellable
optional #GCancellable object, None to ignore
callback
a #GAsyncReadyCallback to call when the request is done
pub fn new_tmp_dir_future( tmpl: Option<impl AsRef<Path>>, io_priority: Priority, ) -> Pin<Box<dyn Future<Output = Result<File, Error>> + 'static>>
v2_74 only.Sourceimpl File
impl File
pub const NONE: Option<&'static File> = None
Sourcepub fn new_build_filenamev(args: &[&Path]) -> File
Available on crate feature v2_78 only.
pub fn new_build_filenamev(args: &[&Path]) -> File
v2_78 only.Sourcepub fn for_commandline_arg(arg: impl AsRef<OsStr>) -> File
pub fn for_commandline_arg(arg: impl AsRef<OsStr>) -> File
Creates a #GFile with the given argument from the command line. The value of @arg can be either a URI, an absolute path or a relative path resolved relative to the current working directory. This operation never fails, but the returned object might not support any I/O operation if @arg points to a malformed path.
Note that on Windows, this function expects its argument to be in
UTF-8 – not the system code page. This means that you
should not use this function with string from argv as it is passed
to main(). g_win32_get_command_line() will return a UTF-8 version of
the commandline. #GApplication also uses UTF-8 but
g_application_command_line_create_file_for_arg() may be more useful
for you there. It is also always possible to use this function with
#GOptionContext arguments of type glib::OptionArg::Filename.
arg
a command line string
Returns
a new #GFile. Free the returned object with g_object_unref().
Sourcepub fn for_commandline_arg_and_cwd(
arg: impl AsRef<OsStr>,
cwd: impl AsRef<Path>,
) -> File
pub fn for_commandline_arg_and_cwd( arg: impl AsRef<OsStr>, cwd: impl AsRef<Path>, ) -> File
Creates a #GFile with the given argument from the command line.
This function is similar to g_file_new_for_commandline_arg() except that it allows for passing the current working directory as an argument instead of using the current working directory of the process.
This is useful if the commandline argument was given in a context other than the invocation of the current process.
See also g_application_command_line_create_file_for_arg().
arg
a command line string
cwd
the current working directory of the commandline
Returns
a new #GFile
Sourcepub fn for_path(path: impl AsRef<Path>) -> File
pub fn for_path(path: impl AsRef<Path>) -> File
Constructs a #GFile for a given path. This operation never fails, but the returned object might not support any I/O operation if @path is malformed.
path
a string containing a relative or absolute path. The string must be encoded in the glib filename encoding.
Returns
a new #GFile for the given @path. Free the returned object with g_object_unref().
Sourcepub fn for_uri(uri: &str) -> File
pub fn for_uri(uri: &str) -> File
Constructs a #GFile for a given URI. This operation never fails, but the returned object might not support any I/O operation if @uri is malformed or if the uri type is not supported.
uri
a UTF-8 string containing a URI
Returns
a new #GFile for the given @uri. Free the returned object with g_object_unref().
Sourcepub fn new_tmp(
tmpl: Option<impl AsRef<Path>>,
) -> Result<(File, FileIOStream), Error>
pub fn new_tmp( tmpl: Option<impl AsRef<Path>>, ) -> Result<(File, FileIOStream), Error>
Opens a file in the preferred directory for temporary files (as returned by g_get_tmp_dir()) and returns a #GFile and #GFileIOStream pointing to it.
@tmpl should be a string in the GLib file name encoding
containing a sequence of six ‘X’ characters, and containing no
directory components. If it is None, a default template is used.
Unlike the other #GFile constructors, this will return None if
a temporary file could not be created.
tmpl
Template for the file
name, as in g_file_open_tmp(), or None for a default template
Returns
a new #GFile. Free the returned object with g_object_unref().
iostream
on return, a #GFileIOStream for the created file
Sourcepub fn for_parse_name(parse_name: &str) -> File
pub fn for_parse_name(parse_name: &str) -> File