Struct gio::FileCopyFlags
source · [−]pub struct FileCopyFlags { /* private fields */ }Implementations
sourceimpl FileCopyFlags
impl FileCopyFlags
pub const NONE: FileCopyFlags = _
pub const OVERWRITE: FileCopyFlags = _
pub const BACKUP: FileCopyFlags = _
pub const NOFOLLOW_SYMLINKS: FileCopyFlags = _
pub const ALL_METADATA: FileCopyFlags = _
pub const NO_FALLBACK_FOR_MOVE: FileCopyFlags = _
pub const TARGET_DEFAULT_PERMS: FileCopyFlags = _
sourcepub const fn empty() -> FileCopyFlags
pub const fn empty() -> FileCopyFlags
Returns an empty set of flags
sourcepub const fn all() -> FileCopyFlags
pub const fn all() -> FileCopyFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileCopyFlags>
pub fn from_bits(bits: u32) -> Option<FileCopyFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileCopyFlags
pub const fn from_bits_truncate(bits: u32) -> FileCopyFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileCopyFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileCopyFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileCopyFlags) -> bool
pub const fn intersects(&self, other: FileCopyFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileCopyFlags) -> bool
pub const fn contains(&self, other: FileCopyFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileCopyFlags)
pub fn insert(&mut self, other: FileCopyFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileCopyFlags)
pub fn remove(&mut self, other: FileCopyFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileCopyFlags)
pub fn toggle(&mut self, other: FileCopyFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileCopyFlags, value: bool)
pub fn set(&mut self, other: FileCopyFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.