Struct gio::FileCreateFlags
source · [−]pub struct FileCreateFlags { /* private fields */ }Implementations
sourceimpl FileCreateFlags
impl FileCreateFlags
pub const NONE: FileCreateFlags = _
pub const PRIVATE: FileCreateFlags = _
pub const REPLACE_DESTINATION: FileCreateFlags = _
sourcepub const fn empty() -> FileCreateFlags
pub const fn empty() -> FileCreateFlags
Returns an empty set of flags
sourcepub const fn all() -> FileCreateFlags
pub const fn all() -> FileCreateFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileCreateFlags>
pub fn from_bits(bits: u32) -> Option<FileCreateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileCreateFlags
pub const fn from_bits_truncate(bits: u32) -> FileCreateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileCreateFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileCreateFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileCreateFlags) -> bool
pub const fn intersects(&self, other: FileCreateFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileCreateFlags) -> bool
pub const fn contains(&self, other: FileCreateFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileCreateFlags)
pub fn insert(&mut self, other: FileCreateFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileCreateFlags)
pub fn remove(&mut self, other: FileCreateFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileCreateFlags)
pub fn toggle(&mut self, other: FileCreateFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileCreateFlags, value: bool)
pub fn set(&mut self, other: FileCreateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.