Struct gio::FileMeasureFlags
source · [−]pub struct FileMeasureFlags { /* private fields */ }Implementations
sourceimpl FileMeasureFlags
impl FileMeasureFlags
pub const NONE: FileMeasureFlags = _
pub const REPORT_ANY_ERROR: FileMeasureFlags = _
pub const APPARENT_SIZE: FileMeasureFlags = _
pub const NO_XDEV: FileMeasureFlags = _
sourcepub const fn empty() -> FileMeasureFlags
pub const fn empty() -> FileMeasureFlags
Returns an empty set of flags
sourcepub const fn all() -> FileMeasureFlags
pub const fn all() -> FileMeasureFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileMeasureFlags>
pub fn from_bits(bits: u32) -> Option<FileMeasureFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileMeasureFlags
pub const fn from_bits_truncate(bits: u32) -> FileMeasureFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileMeasureFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileMeasureFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileMeasureFlags) -> bool
pub const fn intersects(&self, other: FileMeasureFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileMeasureFlags) -> bool
pub const fn contains(&self, other: FileMeasureFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileMeasureFlags)
pub fn insert(&mut self, other: FileMeasureFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileMeasureFlags)
pub fn remove(&mut self, other: FileMeasureFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileMeasureFlags)
pub fn toggle(&mut self, other: FileMeasureFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileMeasureFlags, value: bool)
pub fn set(&mut self, other: FileMeasureFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.