Struct gio::FileMonitorFlags
source · [−]pub struct FileMonitorFlags { /* private fields */ }Implementations
sourceimpl FileMonitorFlags
impl FileMonitorFlags
pub const NONE: FileMonitorFlags = _
pub const WATCH_MOUNTS: FileMonitorFlags = _
pub const SEND_MOVED: FileMonitorFlags = _
pub const WATCH_HARD_LINKS: FileMonitorFlags = _
pub const WATCH_MOVES: FileMonitorFlags = _
sourcepub const fn empty() -> FileMonitorFlags
pub const fn empty() -> FileMonitorFlags
Returns an empty set of flags
sourcepub const fn all() -> FileMonitorFlags
pub const fn all() -> FileMonitorFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileMonitorFlags>
pub fn from_bits(bits: u32) -> Option<FileMonitorFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileMonitorFlags
pub const fn from_bits_truncate(bits: u32) -> FileMonitorFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileMonitorFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileMonitorFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileMonitorFlags) -> bool
pub const fn intersects(&self, other: FileMonitorFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileMonitorFlags) -> bool
pub const fn contains(&self, other: FileMonitorFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileMonitorFlags)
pub fn insert(&mut self, other: FileMonitorFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileMonitorFlags)
pub fn remove(&mut self, other: FileMonitorFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileMonitorFlags)
pub fn toggle(&mut self, other: FileMonitorFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileMonitorFlags, value: bool)
pub fn set(&mut self, other: FileMonitorFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.