Struct gio::FileOutputStreamClass
source · [−]#[repr(C)]pub struct FileOutputStreamClass(_);Trait Implementations
sourceimpl Deref for FileOutputStreamClass
impl Deref for FileOutputStreamClass
type Target = <OutputStream as ObjectType>::RustClassType
type Target = <OutputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for FileOutputStreamClass
impl DerefMut for FileOutputStreamClass
sourceimpl IsClassFor for FileOutputStreamClass
impl IsClassFor for FileOutputStreamClass
type Instance = FileOutputStream
type Instance = FileOutputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for FileOutputStreamClass
impl Sync for FileOutputStreamClass