Struct gio::FileQueryInfoFlags
source · [−]pub struct FileQueryInfoFlags { /* private fields */ }Implementations
sourceimpl FileQueryInfoFlags
impl FileQueryInfoFlags
pub const NONE: FileQueryInfoFlags = _
pub const NOFOLLOW_SYMLINKS: FileQueryInfoFlags = _
sourcepub const fn empty() -> FileQueryInfoFlags
pub const fn empty() -> FileQueryInfoFlags
Returns an empty set of flags
sourcepub const fn all() -> FileQueryInfoFlags
pub const fn all() -> FileQueryInfoFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<FileQueryInfoFlags>
pub fn from_bits(bits: u32) -> Option<FileQueryInfoFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> FileQueryInfoFlags
pub const fn from_bits_truncate(bits: u32) -> FileQueryInfoFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> FileQueryInfoFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> FileQueryInfoFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: FileQueryInfoFlags) -> bool
pub const fn intersects(&self, other: FileQueryInfoFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: FileQueryInfoFlags) -> bool
pub const fn contains(&self, other: FileQueryInfoFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: FileQueryInfoFlags)
pub fn insert(&mut self, other: FileQueryInfoFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: FileQueryInfoFlags)
pub fn remove(&mut self, other: FileQueryInfoFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: FileQueryInfoFlags)
pub fn toggle(&mut self, other: FileQueryInfoFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: FileQueryInfoFlags, value: bool)
pub fn set(&mut self, other: FileQueryInfoFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.