pub struct FilterOutputStream { /* private fields */ }Expand description
Base class for output stream implementations that perform some kind of filtering operation on a base stream. Typical examples of filtering operations are character set conversion, compression and byte order flipping.
This is an Abstract Base Class, you cannot instantiate it.
Properties
base-stream
The underlying base stream on which the I/O ops will be done.
Readable | Writeable | Construct Only
close-base-stream
Whether the base stream should be closed when the filter stream is closed.
Readable | Writeable | Construct Only
Implements
FilterOutputStreamExt, OutputStreamExt, [trait@glib::ObjectExt], OutputStreamExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FilterOutputStream
impl FilterOutputStream
pub const NONE: Option<&'static FilterOutputStream> = None