Struct gio::IOStreamSpliceFlags
source · [−]pub struct IOStreamSpliceFlags { /* private fields */ }Implementations
sourceimpl IOStreamSpliceFlags
impl IOStreamSpliceFlags
pub const NONE: IOStreamSpliceFlags = _
pub const CLOSE_STREAM1: IOStreamSpliceFlags = _
pub const CLOSE_STREAM2: IOStreamSpliceFlags = _
pub const WAIT_FOR_BOTH: IOStreamSpliceFlags = _
sourcepub const fn empty() -> IOStreamSpliceFlags
pub const fn empty() -> IOStreamSpliceFlags
Returns an empty set of flags
sourcepub const fn all() -> IOStreamSpliceFlags
pub const fn all() -> IOStreamSpliceFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<IOStreamSpliceFlags>
pub fn from_bits(bits: u32) -> Option<IOStreamSpliceFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> IOStreamSpliceFlags
pub const fn from_bits_truncate(bits: u32) -> IOStreamSpliceFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> IOStreamSpliceFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> IOStreamSpliceFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: IOStreamSpliceFlags) -> bool
pub const fn intersects(&self, other: IOStreamSpliceFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: IOStreamSpliceFlags) -> bool
pub const fn contains(&self, other: IOStreamSpliceFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: IOStreamSpliceFlags)
pub fn insert(&mut self, other: IOStreamSpliceFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: IOStreamSpliceFlags)
pub fn remove(&mut self, other: IOStreamSpliceFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: IOStreamSpliceFlags)
pub fn toggle(&mut self, other: IOStreamSpliceFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: IOStreamSpliceFlags, value: bool)
pub fn set(&mut self, other: IOStreamSpliceFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.