Struct gio::InetSocketAddressClass
source · [−]#[repr(C)]pub struct InetSocketAddressClass(_);Trait Implementations
sourceimpl Deref for InetSocketAddressClass
impl Deref for InetSocketAddressClass
type Target = <SocketAddress as ObjectType>::RustClassType
type Target = <SocketAddress as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for InetSocketAddressClass
impl DerefMut for InetSocketAddressClass
sourceimpl IsClassFor for InetSocketAddressClass
impl IsClassFor for InetSocketAddressClass
type Instance = InetSocketAddress
type Instance = InetSocketAddress
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for InetSocketAddressClass
impl Sync for InetSocketAddressClass