#[repr(transparent)]pub struct LocalTask<V: ValueType> { /* private fields */ }Expand description
LocalTask provides idiomatic access to gio’s GTask API, for
instance by being generic over their value type, while not completely departing
from the underlying C API. LocalTask does not require its value to be Send
and Sync and thus is useful to to implement gio style asynchronous
tasks that run in the glib main loop. If you need to run tasks in threads
see the Task type.
The constructors of LocalTask and Task is marked as unsafe because this API does
not allow to automatically enforce all the invariants required to be a completely
safe abstraction. See the Task type for more details.
Implementations
sourceimpl<V: ValueType> LocalTask<V>
impl<V: ValueType> LocalTask<V>
pub unsafe fn new<S, P, Q>(
source_object: Option<&S>,
cancellable: Option<&P>,
callback: Q
) -> Selfwhere
S: IsA<Object>,
P: IsA<Cancellable>,
Q: FnOnce(LocalTask<V>, Option<&S>) + 'static,
pub fn cancellable(&self) -> Option<Cancellable>
pub fn is_check_cancellable(&self) -> bool
pub fn set_check_cancellable(&self, check_cancellable: bool)
pub fn set_name(&self, name: Option<&str>)
Available on crate feature
v2_60 only.pub fn set_return_on_cancel(&self, return_on_cancel: bool) -> bool
pub fn is_valid(
result: &impl IsA<AsyncResult>,
source_object: Option<&impl IsA<Object>>
) -> bool
pub fn priority(&self) -> Priority
pub fn set_priority(&self, priority: Priority)
pub fn is_completed(&self) -> bool
pub fn context(&self) -> MainContext
pub fn name(&self) -> Option<GString>
Available on crate feature
v2_60 only.pub fn is_return_on_cancel(&self) -> bool
pub fn had_error(&self) -> bool
pub fn connect_completed_notify<F>(&self, f: F) -> SignalHandlerIdwhere
F: Fn(&LocalTask<V>) + 'static,
pub fn return_error_if_cancelled(&self) -> bool
pub fn return_result(self, result: Result<V, Error>)
pub fn propagate(self) -> Result<V, Error>