Struct gio::MemoryInputStreamClass
source · [−]#[repr(C)]pub struct MemoryInputStreamClass(_);Trait Implementations
sourceimpl Deref for MemoryInputStreamClass
impl Deref for MemoryInputStreamClass
type Target = <InputStream as ObjectType>::RustClassType
type Target = <InputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MemoryInputStreamClass
impl DerefMut for MemoryInputStreamClass
sourceimpl IsClassFor for MemoryInputStreamClass
impl IsClassFor for MemoryInputStreamClass
type Instance = MemoryInputStream
type Instance = MemoryInputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MemoryInputStreamClass
impl Sync for MemoryInputStreamClass