Struct gio::MenuAttributeIterClass
source · [−]#[repr(C)]pub struct MenuAttributeIterClass(_);Trait Implementations
sourceimpl Deref for MenuAttributeIterClass
impl Deref for MenuAttributeIterClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuAttributeIterClass
impl DerefMut for MenuAttributeIterClass
sourceimpl IsClassFor for MenuAttributeIterClass
impl IsClassFor for MenuAttributeIterClass
type Instance = MenuAttributeIter
type Instance = MenuAttributeIter
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuAttributeIterClass
impl Sync for MenuAttributeIterClass