Struct gio::MenuLinkIterClass
source · [−]#[repr(C)]pub struct MenuLinkIterClass(_);Trait Implementations
sourceimpl Deref for MenuLinkIterClass
impl Deref for MenuLinkIterClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for MenuLinkIterClass
impl DerefMut for MenuLinkIterClass
sourceimpl IsClassFor for MenuLinkIterClass
impl IsClassFor for MenuLinkIterClass
type Instance = MenuLinkIter
type Instance = MenuLinkIter
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for MenuLinkIterClass
impl Sync for MenuLinkIterClass