Struct gio::MountMountFlags
source · [−]pub struct MountMountFlags { /* private fields */ }Implementations
sourceimpl MountMountFlags
impl MountMountFlags
pub const NONE: MountMountFlags = _
sourcepub const fn empty() -> MountMountFlags
pub const fn empty() -> MountMountFlags
Returns an empty set of flags
sourcepub const fn all() -> MountMountFlags
pub const fn all() -> MountMountFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<MountMountFlags>
pub fn from_bits(bits: u32) -> Option<MountMountFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> MountMountFlags
pub const fn from_bits_truncate(bits: u32) -> MountMountFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> MountMountFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> MountMountFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: MountMountFlags) -> bool
pub const fn intersects(&self, other: MountMountFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: MountMountFlags) -> bool
pub const fn contains(&self, other: MountMountFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: MountMountFlags)
pub fn insert(&mut self, other: MountMountFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: MountMountFlags)
pub fn remove(&mut self, other: MountMountFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: MountMountFlags)
pub fn toggle(&mut self, other: MountMountFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: MountMountFlags, value: bool)
pub fn set(&mut self, other: MountMountFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.