Struct gio::MountUnmountFlags
source · [−]pub struct MountUnmountFlags { /* private fields */ }Implementations
sourceimpl MountUnmountFlags
impl MountUnmountFlags
pub const NONE: MountUnmountFlags = _
pub const FORCE: MountUnmountFlags = _
sourcepub const fn empty() -> MountUnmountFlags
pub const fn empty() -> MountUnmountFlags
Returns an empty set of flags
sourcepub const fn all() -> MountUnmountFlags
pub const fn all() -> MountUnmountFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<MountUnmountFlags>
pub fn from_bits(bits: u32) -> Option<MountUnmountFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> MountUnmountFlags
pub const fn from_bits_truncate(bits: u32) -> MountUnmountFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> MountUnmountFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> MountUnmountFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: MountUnmountFlags) -> bool
pub const fn intersects(&self, other: MountUnmountFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: MountUnmountFlags) -> bool
pub const fn contains(&self, other: MountUnmountFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: MountUnmountFlags)
pub fn insert(&mut self, other: MountUnmountFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: MountUnmountFlags)
pub fn remove(&mut self, other: MountUnmountFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: MountUnmountFlags)
pub fn toggle(&mut self, other: MountUnmountFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: MountUnmountFlags, value: bool)
pub fn set(&mut self, other: MountUnmountFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.