Struct gio::OutputStreamSpliceFlags
source · [−]pub struct OutputStreamSpliceFlags { /* private fields */ }Implementations
sourceimpl OutputStreamSpliceFlags
impl OutputStreamSpliceFlags
pub const NONE: OutputStreamSpliceFlags = _
pub const CLOSE_SOURCE: OutputStreamSpliceFlags = _
pub const CLOSE_TARGET: OutputStreamSpliceFlags = _
sourcepub const fn empty() -> OutputStreamSpliceFlags
pub const fn empty() -> OutputStreamSpliceFlags
Returns an empty set of flags
sourcepub const fn all() -> OutputStreamSpliceFlags
pub const fn all() -> OutputStreamSpliceFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<OutputStreamSpliceFlags>
pub fn from_bits(bits: u32) -> Option<OutputStreamSpliceFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> OutputStreamSpliceFlags
pub const fn from_bits_truncate(bits: u32) -> OutputStreamSpliceFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> OutputStreamSpliceFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> OutputStreamSpliceFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: OutputStreamSpliceFlags) -> bool
pub const fn intersects(&self, other: OutputStreamSpliceFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: OutputStreamSpliceFlags) -> bool
pub const fn contains(&self, other: OutputStreamSpliceFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: OutputStreamSpliceFlags)
pub fn insert(&mut self, other: OutputStreamSpliceFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: OutputStreamSpliceFlags)
pub fn remove(&mut self, other: OutputStreamSpliceFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: OutputStreamSpliceFlags)
pub fn toggle(&mut self, other: OutputStreamSpliceFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: OutputStreamSpliceFlags, value: bool)
pub fn set(&mut self, other: OutputStreamSpliceFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.