Struct gio::PermissionClass
source · [−]#[repr(C)]pub struct PermissionClass(_);Trait Implementations
sourceimpl Deref for PermissionClass
impl Deref for PermissionClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for PermissionClass
impl DerefMut for PermissionClass
sourceimpl IsClassFor for PermissionClass
impl IsClassFor for PermissionClass
type Instance = Permission
type Instance = Permission
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for PermissionClass
impl Sync for PermissionClass