Struct gio::ProxyAddressClass
source · [−]#[repr(C)]pub struct ProxyAddressClass(_);Trait Implementations
sourceimpl Deref for ProxyAddressClass
impl Deref for ProxyAddressClass
type Target = <InetSocketAddress as ObjectType>::RustClassType
type Target = <InetSocketAddress as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ProxyAddressClass
impl DerefMut for ProxyAddressClass
sourceimpl IsClassFor for ProxyAddressClass
impl IsClassFor for ProxyAddressClass
type Instance = ProxyAddress
type Instance = ProxyAddress
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ProxyAddressClass
impl Sync for ProxyAddressClass