Struct gio::SettingsBindFlags
source · [−]pub struct SettingsBindFlags { /* private fields */ }Implementations
sourceimpl SettingsBindFlags
impl SettingsBindFlags
pub const DEFAULT: SettingsBindFlags = _
pub const GET: SettingsBindFlags = _
pub const SET: SettingsBindFlags = _
pub const NO_SENSITIVITY: SettingsBindFlags = _
pub const GET_NO_CHANGES: SettingsBindFlags = _
pub const INVERT_BOOLEAN: SettingsBindFlags = _
sourcepub const fn empty() -> SettingsBindFlags
pub const fn empty() -> SettingsBindFlags
Returns an empty set of flags
sourcepub const fn all() -> SettingsBindFlags
pub const fn all() -> SettingsBindFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<SettingsBindFlags>
pub fn from_bits(bits: u32) -> Option<SettingsBindFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> SettingsBindFlags
pub const fn from_bits_truncate(bits: u32) -> SettingsBindFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> SettingsBindFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> SettingsBindFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: SettingsBindFlags) -> bool
pub const fn intersects(&self, other: SettingsBindFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: SettingsBindFlags) -> bool
pub const fn contains(&self, other: SettingsBindFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: SettingsBindFlags)
pub fn insert(&mut self, other: SettingsBindFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: SettingsBindFlags)
pub fn remove(&mut self, other: SettingsBindFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: SettingsBindFlags)
pub fn toggle(&mut self, other: SettingsBindFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: SettingsBindFlags, value: bool)
pub fn set(&mut self, other: SettingsBindFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.