Struct gio::SimpleActionGroupClass
source · [−]#[repr(C)]pub struct SimpleActionGroupClass(_);Trait Implementations
sourceimpl Deref for SimpleActionGroupClass
impl Deref for SimpleActionGroupClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SimpleActionGroupClass
impl DerefMut for SimpleActionGroupClass
sourceimpl IsClassFor for SimpleActionGroupClass
impl IsClassFor for SimpleActionGroupClass
type Instance = SimpleActionGroup
type Instance = SimpleActionGroup
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SimpleActionGroupClass
impl Sync for SimpleActionGroupClass