Struct gio::SimplePermissionClass
source · [−]#[repr(C)]pub struct SimplePermissionClass(_);Trait Implementations
sourceimpl Deref for SimplePermissionClass
impl Deref for SimplePermissionClass
type Target = <Permission as ObjectType>::RustClassType
type Target = <Permission as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SimplePermissionClass
impl DerefMut for SimplePermissionClass
sourceimpl IsClassFor for SimplePermissionClass
impl IsClassFor for SimplePermissionClass
type Instance = SimplePermission
type Instance = SimplePermission
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SimplePermissionClass
impl Sync for SimplePermissionClass