Socket

Struct Socket 

pub struct Socket { /* private fields */ }
local_error); // handle error if needed }



## Properties


#### `blocking`
 Whether I/O on this socket is blocking.

Readable | Writable


#### `broadcast`
 Whether the socket should allow sending to broadcast addresses.

Readable | Writable


#### `family`
 s address family.

Readable | Writable | Construct Only


#### `fd`
 s file descriptor.

Readable | Writable | Construct Only


#### `keepalive`
 Whether to keep the connection alive by sending periodic pings.

Readable | Writable


#### `listen-backlog`
 The number of outstanding connections in the listen queue.

Readable | Writable


#### `local-address`
 The local address the socket is bound to.

Readable


#### `multicast-loopback`
 Whether outgoing multicast packets loop back to the local host.

Readable | Writable


#### `multicast-ttl`
 Time-to-live out outgoing multicast packets

Readable | Writable


#### `protocol`
 The ID of the protocol to use, or `-1` for unknown.

Readable | Writable | Construct Only


#### `remote-address`
 The remote address the socket is connected to.

Readable


#### `timeout`
 The timeout in seconds on socket I/O

Readable | Writable


#### `ttl`
 Time-to-live for outgoing unicast packets

Readable | Writable


#### `type`
 s type.

Readable | Writable | Construct Only

# Implements

[`SocketExt`][trait@crate::prelude::SocketExt], [`trait@glib::ObjectExt`], [`DatagramBasedExt`][trait@crate::prelude::DatagramBasedExt], [`InitableExt`][trait@crate::prelude::InitableExt], [`SocketExtManual`][trait@crate::prelude::SocketExtManual], [`DatagramBasedExtManual`][trait@crate::prelude::DatagramBasedExtManual]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Socket

pub fn from_fd(fd: OwnedFd) -> Result<Socket, Error>

Available on Unix only.

Creates a new #GSocket from a native file descriptor or winsock SOCKET handle.

This reads all the settings from the file descriptor so that all properties should work. Note that the file descriptor will be set to non-blocking mode, independent on the blocking mode of the #GSocket.

On success, the returned #GSocket takes ownership of @fd. On failure, the caller must close @fd themselves.

Since GLib 2.46, it is no longer a fatal error to call this on a non-socket descriptor. Instead, a GError will be set with code IOErrorEnum::Failed

fd

a native socket file descriptor.

Returns

a #GSocket or None on error. Free the returned object with g_object_unref().

pub unsafe fn from_raw_fd(fd: impl IntoRawFd) -> Result<Socket, Error>

Available on Unix only.
Source

impl Socket

pub const NONE: Option<&'static Socket> = None

pub fn new( family: SocketFamily, type_: SocketType, protocol: SocketProtocol, ) -> Result<Socket, Error>

Creates a new #GSocket with the defined family, type and protocol. If @protocol is 0 (SocketProtocol::Default) the default protocol type for the family and type is used.

The @protocol is a family and type specific int that specifies what kind of protocol to use. #GSocketProtocol lists several common ones. Many families only support one protocol, and use 0 for this, others support several and using 0 means to use the default protocol for the family and type.

The protocol id is passed directly to the operating system, so you can use protocols not listed in #GSocketProtocol if you know the protocol number used for it.

family

the socket family to use, e.g. SocketFamily::Ipv4.

type_

the socket type to use.

protocol

the id of the protocol to use, or 0 for default.

Returns

a #GSocket or None on error. Free the returned object with g_object_unref().