Struct gio::SocketClientClass
source · [−]#[repr(C)]pub struct SocketClientClass(_);Trait Implementations
sourceimpl Deref for SocketClientClass
impl Deref for SocketClientClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SocketClientClass
impl DerefMut for SocketClientClass
sourceimpl IsClassFor for SocketClientClass
impl IsClassFor for SocketClientClass
type Instance = SocketClient
type Instance = SocketClient
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SocketClientClass
impl Sync for SocketClientClass