Struct gio::SocketConnectionClass
source · [−]#[repr(C)]pub struct SocketConnectionClass(_);Trait Implementations
sourceimpl Deref for SocketConnectionClass
impl Deref for SocketConnectionClass
type Target = <IOStream as ObjectType>::RustClassType
type Target = <IOStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SocketConnectionClass
impl DerefMut for SocketConnectionClass
sourceimpl IsClassFor for SocketConnectionClass
impl IsClassFor for SocketConnectionClass
type Instance = SocketConnection
type Instance = SocketConnection
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SocketConnectionClass
impl Sync for SocketConnectionClass