Struct gio::SocketServiceClass
source · [−]#[repr(C)]pub struct SocketServiceClass(_);Trait Implementations
sourceimpl Deref for SocketServiceClass
impl Deref for SocketServiceClass
type Target = <SocketListener as ObjectType>::RustClassType
type Target = <SocketListener as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SocketServiceClass
impl DerefMut for SocketServiceClass
sourceimpl IsClassFor for SocketServiceClass
impl IsClassFor for SocketServiceClass
type Instance = SocketService
type Instance = SocketService
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SocketServiceClass
impl Sync for SocketServiceClass