pub struct SrvTarget { /* private fields */ }Expand description
s
SocketConnectable interface and not need to worry about
GSrvTarget at all.
GLib type: Boxed type with copy-on-clone semantics.
Implementations
Sourceimpl SrvTarget
impl SrvTarget
Sourcepub fn as_ptr(&self) -> *mut GSrvTarget
pub fn as_ptr(&self) -> *mut GSrvTarget
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut GSrvTarget) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut GSrvTarget) -> &Self
Borrows the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow_mut(ptr: &mut *mut GSrvTarget) -> &mut Self
pub unsafe fn from_glib_ptr_borrow_mut(ptr: &mut *mut GSrvTarget) -> &mut Self
Borrows the underlying C value mutably.
Sourceimpl SrvTarget
impl SrvTarget
Sourcepub fn new(hostname: &str, port: u16, priority: u16, weight: u16) -> SrvTarget
pub fn new(hostname: &str, port: u16, priority: u16, weight: u16) -> SrvTarget
Creates a new #GSrvTarget with the given parameters.
You should not need to use this; normally #GSrvTargets are created by #GResolver.
hostname
the host that the service is running on
port
the port that the service is running on
priority
the target’s priority
weight
the target’s weight
Returns
a new #GSrvTarget.
Sourcepub fn hostname(&mut self) -> GString
pub fn hostname(&mut self) -> GString
Gets @self’s hostname (in ASCII form; if you are going to present this to the user, you should use g_hostname_is_ascii_encoded() to check if it contains encoded Unicode segments, and use g_hostname_to_unicode() to convert it if it does.)
Returns
@self’s hostname