Struct gio::SubprocessLauncherClass
source · [−]#[repr(C)]pub struct SubprocessLauncherClass(_);Trait Implementations
sourceimpl Deref for SubprocessLauncherClass
impl Deref for SubprocessLauncherClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for SubprocessLauncherClass
impl DerefMut for SubprocessLauncherClass
sourceimpl IsClassFor for SubprocessLauncherClass
impl IsClassFor for SubprocessLauncherClass
type Instance = SubprocessLauncher
type Instance = SubprocessLauncher
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for SubprocessLauncherClass
impl Sync for SubprocessLauncherClass