Struct gio::ThemedIconClass
source · [−]#[repr(C)]pub struct ThemedIconClass(_);Trait Implementations
sourceimpl Deref for ThemedIconClass
impl Deref for ThemedIconClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for ThemedIconClass
impl DerefMut for ThemedIconClass
sourceimpl IsClassFor for ThemedIconClass
impl IsClassFor for ThemedIconClass
type Instance = ThemedIcon
type Instance = ThemedIcon
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for ThemedIconClass
impl Sync for ThemedIconClass