Struct gio::TlsCertificateFlags
source · [−]pub struct TlsCertificateFlags { /* private fields */ }Implementations
sourceimpl TlsCertificateFlags
impl TlsCertificateFlags
pub const UNKNOWN_CA: TlsCertificateFlags = _
pub const BAD_IDENTITY: TlsCertificateFlags = _
pub const NOT_ACTIVATED: TlsCertificateFlags = _
pub const EXPIRED: TlsCertificateFlags = _
pub const REVOKED: TlsCertificateFlags = _
pub const INSECURE: TlsCertificateFlags = _
pub const GENERIC_ERROR: TlsCertificateFlags = _
pub const VALIDATE_ALL: TlsCertificateFlags = _
sourcepub const fn empty() -> TlsCertificateFlags
pub const fn empty() -> TlsCertificateFlags
Returns an empty set of flags
sourcepub const fn all() -> TlsCertificateFlags
pub const fn all() -> TlsCertificateFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TlsCertificateFlags>
pub fn from_bits(bits: u32) -> Option<TlsCertificateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TlsCertificateFlags
pub const fn from_bits_truncate(bits: u32) -> TlsCertificateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TlsCertificateFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TlsCertificateFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TlsCertificateFlags) -> bool
pub const fn intersects(&self, other: TlsCertificateFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TlsCertificateFlags) -> bool
pub const fn contains(&self, other: TlsCertificateFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TlsCertificateFlags)
pub fn insert(&mut self, other: TlsCertificateFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TlsCertificateFlags)
pub fn remove(&mut self, other: TlsCertificateFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TlsCertificateFlags)
pub fn toggle(&mut self, other: TlsCertificateFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TlsCertificateFlags, value: bool)
pub fn set(&mut self, other: TlsCertificateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.