Struct gio::TlsConnectionClass
source · [−]#[repr(C)]pub struct TlsConnectionClass(_);Trait Implementations
sourceimpl Deref for TlsConnectionClass
impl Deref for TlsConnectionClass
type Target = <IOStream as ObjectType>::RustClassType
type Target = <IOStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for TlsConnectionClass
impl DerefMut for TlsConnectionClass
sourceimpl IsClassFor for TlsConnectionClass
impl IsClassFor for TlsConnectionClass
type Instance = TlsConnection
type Instance = TlsConnection
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for TlsConnectionClass
impl Sync for TlsConnectionClass