Struct gio::TlsDatabaseVerifyFlags
source · [−]pub struct TlsDatabaseVerifyFlags { /* private fields */ }Implementations
sourceimpl TlsDatabaseVerifyFlags
impl TlsDatabaseVerifyFlags
pub const NONE: TlsDatabaseVerifyFlags = _
sourcepub const fn empty() -> TlsDatabaseVerifyFlags
pub const fn empty() -> TlsDatabaseVerifyFlags
Returns an empty set of flags
sourcepub const fn all() -> TlsDatabaseVerifyFlags
pub const fn all() -> TlsDatabaseVerifyFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TlsDatabaseVerifyFlags>
pub fn from_bits(bits: u32) -> Option<TlsDatabaseVerifyFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TlsDatabaseVerifyFlags
pub const fn from_bits_truncate(bits: u32) -> TlsDatabaseVerifyFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TlsDatabaseVerifyFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TlsDatabaseVerifyFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TlsDatabaseVerifyFlags) -> bool
pub const fn intersects(&self, other: TlsDatabaseVerifyFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TlsDatabaseVerifyFlags) -> bool
pub const fn contains(&self, other: TlsDatabaseVerifyFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TlsDatabaseVerifyFlags)
pub fn insert(&mut self, other: TlsDatabaseVerifyFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TlsDatabaseVerifyFlags)
pub fn remove(&mut self, other: TlsDatabaseVerifyFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TlsDatabaseVerifyFlags)
pub fn toggle(&mut self, other: TlsDatabaseVerifyFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TlsDatabaseVerifyFlags, value: bool)
pub fn set(&mut self, other: TlsDatabaseVerifyFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.