Struct gio::TlsPasswordFlags
source · [−]pub struct TlsPasswordFlags { /* private fields */ }Implementations
sourceimpl TlsPasswordFlags
impl TlsPasswordFlags
pub const NONE: TlsPasswordFlags = _
pub const RETRY: TlsPasswordFlags = _
pub const MANY_TRIES: TlsPasswordFlags = _
pub const FINAL_TRY: TlsPasswordFlags = _
sourcepub const fn empty() -> TlsPasswordFlags
pub const fn empty() -> TlsPasswordFlags
Returns an empty set of flags
sourcepub const fn all() -> TlsPasswordFlags
pub const fn all() -> TlsPasswordFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<TlsPasswordFlags>
pub fn from_bits(bits: u32) -> Option<TlsPasswordFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> TlsPasswordFlags
pub const fn from_bits_truncate(bits: u32) -> TlsPasswordFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TlsPasswordFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> TlsPasswordFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: TlsPasswordFlags) -> bool
pub const fn intersects(&self, other: TlsPasswordFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: TlsPasswordFlags) -> bool
pub const fn contains(&self, other: TlsPasswordFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: TlsPasswordFlags)
pub fn insert(&mut self, other: TlsPasswordFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: TlsPasswordFlags)
pub fn remove(&mut self, other: TlsPasswordFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: TlsPasswordFlags)
pub fn toggle(&mut self, other: TlsPasswordFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: TlsPasswordFlags, value: bool)
pub fn set(&mut self, other: TlsPasswordFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.