Struct gio::UnixInputStreamClass
source · [−]#[repr(C)]pub struct UnixInputStreamClass(_);Trait Implementations
sourceimpl Deref for UnixInputStreamClass
impl Deref for UnixInputStreamClass
type Target = <InputStream as ObjectType>::RustClassType
type Target = <InputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for UnixInputStreamClass
impl DerefMut for UnixInputStreamClass
sourceimpl IsClassFor for UnixInputStreamClass
impl IsClassFor for UnixInputStreamClass
type Instance = UnixInputStream
type Instance = UnixInputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for UnixInputStreamClass
impl Sync for UnixInputStreamClass