Struct gio::UnixOutputStreamClass
source · [−]#[repr(C)]pub struct UnixOutputStreamClass(_);Trait Implementations
sourceimpl Deref for UnixOutputStreamClass
impl Deref for UnixOutputStreamClass
type Target = <OutputStream as ObjectType>::RustClassType
type Target = <OutputStream as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for UnixOutputStreamClass
impl DerefMut for UnixOutputStreamClass
sourceimpl IsClassFor for UnixOutputStreamClass
impl IsClassFor for UnixOutputStreamClass
type Instance = UnixOutputStream
type Instance = UnixOutputStream
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for UnixOutputStreamClass
impl Sync for UnixOutputStreamClass