Trait ListModelExtManual Copy item path Source pub trait ListModelExtManual: IsA <ListModel > + Sized {
// Provided methods
fn snapshot (&self) -> Vec <Object > { ... }
fn iter <LT: IsA <Object >>(&self) -> ListModelIter<'_, LT> { ... }
}Get an immutable snapshot of the container inside the ListModel.
Any modification done to the returned container Vec will not be
reflected on the ListModel.
If T::static_type().is_a(self.item_type()) then it returns an iterator over the ListModel elements,
else the types are not compatible and it panics.
 Panics
Panics if T::static_type().is_a(self.item_type()) is not true.
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".