Struct gio::FileQueryInfoFlags [−][src]
Implementations
impl FileQueryInfoFlags[src]
pub const NONE: FileQueryInfoFlags[src]
pub const NOFOLLOW_SYMLINKS: FileQueryInfoFlags[src]
pub fn empty() -> FileQueryInfoFlags[src]
Returns an empty set of flags.
pub fn all() -> FileQueryInfoFlags[src]
Returns the set containing all flags.
pub fn bits(&self) -> u32[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FileQueryInfoFlags>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FileQueryInfoFlags[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub fn intersects(&self, other: FileQueryInfoFlags) -> bool[src]
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: FileQueryInfoFlags) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FileQueryInfoFlags)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: FileQueryInfoFlags)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: FileQueryInfoFlags)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: FileQueryInfoFlags, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.