[−]Struct gio::Notification
Notification is a mechanism for creating a notification to be shown
to the user -- typically as a pop-up notification presented by the
desktop environment shell.
The key difference between Notification and other similar APIs is
that, if supported by the desktop environment, notifications sent
with Notification will persist after the application has exited,
and even across system reboots.
Since the user may click on a notification while the application is
not running, applications using Notification should be able to be
started as a D-Bus service, using Application.
User interaction with a notification (either the default action, or buttons) must be associated with actions on the application (ie: "app." actions). It is not possible to route user interaction through the notification itself, because the object will not exist if the application is autostarted as a result of a notification being clicked.
A notification can be sent with ApplicationExt::send_notification.
Feature: v2_40
Implements
Methods
impl Notification[src]
impl Notificationpub fn new(title: &str) -> Notification[src]
pub fn new(title: &str) -> NotificationCreates a new Notification with title as its title.
After populating notification with more details, it can be sent to
the desktop shell with ApplicationExt::send_notification. Changing
any properties after this call will not have any effect until
resending notification.
Feature: v2_40
title
the title of the notification
Returns
a new Notification instance