pub struct Settings { /* private fields */ }Expand description
elements which have a l10n` attribute set.
Translations must not be included in the .gschema.xml file by the build
system, for example by using a rule to generate the XML file from a template.
Properties
backend
The name of the context that the settings are stored in.
Readable | Writable | Construct Only
delay-apply
mode](class.Settings.html#delay-apply-mode).
Readable
has-unapplied
Whether the Settings object has outstanding changes.
These changes will be applied when SettingsExt::apply() is called.
Readable
path
The path within the backend where the settings are stored.
Readable | Writable | Construct Only
schema
The name of the schema that describes the types of keys
for this Settings object.
The type of this property is not SettingsSchema.
SettingsSchema has only existed since version 2.32 and
unfortunately this name was used in previous versions to refer to
the schema ID rather than the schema itself. Take care to use the
settings-schema property if you wish to pass in a
SettingsSchema.
Readable | Writable | Construct Only
schema-id
The name of the schema that describes the types of keys
for this Settings object.
Readable | Writable | Construct Only
settings-schema
The SettingsSchema describing the types of keys for this
Settings object.
Ideally, this property would be called schema.
SettingsSchema
has only existed since version 2.32, however, and before then the
schema property was used to refer to the ID of the schema rather
than the schema itself. Take care.
Readable | Writable | Construct Only
Signals
change-event
Emitted once per change event that affects this settings object.
You should connect to this signal
only if you are interested in viewing groups of changes before they
are split out into multiple emissions of the changed signal.
For most use cases it is more appropriate to use the changed signal.
In the event that the change event applies to one or more specified
keys, @keys will be an array of alias::GLib.Quarks of length @n_keys. In the
event that the change event applies to the Settings object as a
whole (ie: potentially every key has been changed) then @keys will
be NULL and @n_keys will be 0.
The default handler for this signal invokes the changed signal
for each affected key. If any other connected handler returns
true then this default functionality will be suppressed.
changed
Emitted when a key has potentially changed.
You should call one of the Gio::Settings::get() calls to check the new
value.
This signal supports detailed connections. You can connect to the
detailed signal changed::x in order to only receive callbacks
when key x changes.
Note that @settings only emits this signal if you have read @key at least once while a signal handler was already connected for @key.
Detailed
writable-change-event
Emitted once per writability change event that affects this settings object.
You should connect
to this signal if you are interested in viewing groups of changes
before they are split out into multiple emissions of the
writable-changed signal. For most use cases it is more
appropriate to use the writable-changed signal.
In the event that the writability change applies only to a single
key, @key will be set to the alias::GLib.Quark for that key. In the event
that the writability change affects the entire settings object,
@key will be 0.
The default handler for this signal invokes the writable-changed
and changed signals for each affected key. This is done because
changes in writability might also imply changes in value (if for
example, a new mandatory setting is introduced). If any other
connected handler returns true then this default functionality
will be suppressed.
writable-changed
Emitted when the writability of a key has potentially changed.
You should call SettingsExt::is_writable() in order to determine the
new status.
This signal supports detailed connections. You can connect to the
detailed signal writable-changed::x in order to only receive
callbacks when the writability of x changes.
Detailed
Implements
SettingsExt, [trait@glib::ObjectExt], SettingsExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Settings
impl Settings
pub const NONE: Option<&'static Settings> = None
Sourcepub fn new(schema_id: &str) -> Settings
pub fn new(schema_id: &str) -> Settings
Creates a new Settings object with the schema specified by
@schema_id.
It is an error for the schema to not exist: schemas are an
essential part of a program, as they provide type information.
If schemas need to be dynamically loaded (for example, from an
optional runtime dependency), SettingsSchemaSource::lookup()
can be used to test for their existence before loading them.
Signals on the newly created Settings object will be dispatched
via the thread-default glib::MainContext in effect at the time of the
call to new(). The new Settings will hold a reference
on the context. See [glib::MainContext::push_thread_default()][crate::glib::MainContext::push_thread_default()].
schema_id
the ID of the schema
Returns
a new Settings object
Sourcepub fn new_full(
schema: &SettingsSchema,
backend: Option<&impl IsA<SettingsBackend>>,
path: Option<&str>,
) -> Settings
pub fn new_full( schema: &SettingsSchema, backend: Option<&impl IsA<SettingsBackend>>, path: Option<&str>, ) -> Settings
Creates a new Settings object with a given schema, backend and
path.
It should be extremely rare that you ever want to use this function. It is made available for advanced use-cases (such as plugin systems that want to provide access to schemas loaded from custom locations, etc).
At the most basic level, a Settings object is a pure composition of
four things: a SettingsSchema, a SettingsBackend, a path within that
backend, and a glib::MainContext to which signals are dispatched.
This constructor therefore gives you full control over constructing
Settings instances. The first 3 parameters are given directly as
@schema, @backend and @path, and the main context is taken from the
thread-default (as per new()).
If @backend is NULL then the default backend is used.
If @path is NULL then the path from the schema is used. It is an
error if @path is NULL and the schema has no path of its own or if
@path is non-NULL and not equal to the path that the schema does
have.
schema
the schema describing the settings
backend
the settings backend to use
path
the path to use
Returns
a new Settings object
Sourcepub fn with_backend(
schema_id: &str,
backend: &impl IsA<SettingsBackend>,
) -> Settings
pub fn with_backend( schema_id: &str, backend: &impl IsA<SettingsBackend>, ) -> Settings
Sourcepub fn with_backend_and_path(
schema_id: &str,
backend: &impl IsA<SettingsBackend>,
path: &str,
) -> Settings
pub fn with_backend_and_path( schema_id: &str, backend: &impl IsA<SettingsBackend>, path: &str, ) -> Settings
Creates a new Settings object with the schema specified by
@schema_id and a given SettingsBackend and path.
This is a mix of with_backend() and
with_path().
schema_id
the ID of the schema
backend
the settings backend to use
path
the path to use
Returns
a new Settings object
Sourcepub fn with_path(schema_id: &str, path: &str) -> Settings
pub fn with_path(schema_id: &str, path: &str) -> Settings
s quite rare.
It is a programmer error to call this function for a schema that has an explicitly specified path.
It is a programmer error if @path is not a valid path. A valid path
begins and ends with / and does not contain two consecutive /
characters.
schema_id
the ID of the schema
path
the path to use
Returns
a new Settings object
Sourcepub fn sync()
pub fn sync()
Ensures that all pending operations are complete for the default backend.
Writes made to a Settings are handled asynchronously. For this
reason, it is very unlikely that the changes have it to disk by the
time Gio::Settings::set() returns.
This call will block until all of the writes have made it to the backend. Since the main loop is not running, no change notifications will be dispatched during this call (but some may be queued by the time the call is done).