pub struct SettingsSchema { /* private fields */ }Expand description
}
It's also possible that the plugin system expects the schema source
files (ie: `.gschema.xml` files) instead of a `gschemas.compiled` file.
In that case, the plugin loading system must compile the schemas for
itself before attempting to create the settings source.
GLib type: Shared boxed type with reference counted clone semantics.Implementations
Sourceimpl SettingsSchema
impl SettingsSchema
Sourcepub fn as_ptr(&self) -> *mut GSettingsSchema
pub fn as_ptr(&self) -> *mut GSettingsSchema
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut GSettingsSchema) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut GSettingsSchema) -> &Self
Borrows the underlying C value.
Sourceimpl SettingsSchema
impl SettingsSchema
Sourcepub fn key(&self, name: &str) -> SettingsSchemaKey
pub fn key(&self, name: &str) -> SettingsSchemaKey
Sourcepub fn path(&self) -> Option<GString>
pub fn path(&self) -> Option<GString>
Gets the path associated with @self, or None.
Schemas may be single-instance or relocatable. Single-instance schemas correspond to exactly one set of keys in the backend database: those located at the path returned by this function.
Relocatable schemas can be referenced by other schemas and can
therefore describe multiple sets of keys at different locations. For
relocatable schemas, this function will return None.
Returns
the path of the schema, or None
Sourcepub fn list_children(&self) -> Vec<GString>
pub fn list_children(&self) -> Vec<GString>
Gets the list of children in @self.
You should free the return value with g_strfreev() when you are done with it.
Returns
a list of the children on @settings, in no defined order
Sourcepub fn list_keys(&self) -> Vec<GString>
pub fn list_keys(&self) -> Vec<GString>
Introspects the list of keys on @self.
You should probably not be calling this function from “normal” code (since you should already know what keys are in your schema). This function is intended for introspection reasons.
Returns
a list of the keys on @self, in no defined order